@@ -1,7 +1,7 @@
 #!/bin/sh
 
+gettextize --force --copy --intl
 aclocal
-gettextize --force --copy
 autoheader
 automake --add-missing --copy
 autoconf
